Documentation
¶
Index ¶
Constants ¶
const ( // MinDealDuration is the minimum allowed deal duration in epochs requested of miners. MinDealDuration = epochsPerDay * 365 / 2 // ~6 months // MaxDealDuration is the maximum allowed deal duration in epochs requested of miners. MaxDealDuration = epochsPerDay * 510 // As far as we know, is the safest max duration that all miners accept. )
const AuctionTopic string = "/textile/auction/0.0.1"
AuctionTopic is used by brokers to publish and by miners to subscribe to deal auction.
Variables ¶
This section is empty.
Functions ¶
func BidsTopic ¶
BidsTopic is used by miners to submit deal auction bids. "/textile/auction/0.0.1/<auction_id>/bids".
func ProposalsTopic ¶
ProposalsTopic is used by brokers to notify a bidbot of the proposal cid.Cid for an accepted deal auction. "/textile/auction/0.0.1/<peer_id>/proposals".
Types ¶
type Bid ¶
type Bid struct {
MinerAddr string
WalletAddrSig []byte
BidderID peer.ID
AskPrice int64 // attoFIL per GiB per epoch
VerifiedAskPrice int64 // attoFIL per GiB per epoch
StartEpoch uint64
FastRetrieval bool
ReceivedAt time.Time
}
Bid defines the core bid model.
type Sources ¶
Sources contains information about download sources for prepared data.
type WinningBid ¶
type WinningBid struct {
BidderID peer.ID
Acknowledged bool // Whether or not the bidder acknowledged receipt of the win
ProposalCid cid.Cid
ProposalCidAcknowledged bool // Whether or not the bidder acknowledged receipt of the proposal Cid
}
WinningBid contains details about a winning bid.
Click to show internal directories.
Click to hide internal directories.